# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn22.03

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 22.03.0
Release: 37%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/v%{version}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit d94cd0d3eec33e4290d7ca81918f5ac61444886e
%define ovsshortcommit d94cd0d

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%if 0%{?commit0:1}
%autosetup -n ovn-%{commit0} -a 10 -p 1
%else
%autosetup -n ovn-%{version} -a 10 -p 1
%endif

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Wed May 18 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-37
- ovn-controller: Consider zone 0 as a valid zone when restoring. (#2087194)
[Gerrit: 7d6d67c824accf8b07a1da0e11c0aa70e8f22431]
[Upstream: 3a8fe34c789f09135c1356ace442793dd6fc2f1c]

* Wed May 18 2022 Mary Manohar <mary.manohar@nutanix.com> - 22.03.0-36
- ovn-controller: Set Port_Binding.up field only if the Southbound DB is aware of this field
[Gerrit: 56a836ce24271a19a0e17e5ac2f70b15e8c8dde9]
[Upstream: 56a836ce24271a19a0e17e5ac2f70b15e8c8dde9]

* Wed May 18 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-35
- northd: Honor ct-snat-zone option for common case. (#2061619)
[Gerrit: f93e36c8e3a30acbbe21c8641b8a4d48289578f0]
[Upstream: f93e36c8e3a30acbbe21c8641b8a4d48289578f0]

* Mon May 16 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-34
- northd: handle container lport type update (#2037433)
[Gerrit: 28d40c0a024227c9c845117087b7594723ff0ec7]
[Upstream: cd3b685043fa9758df3665bf3e3fc972048698a6]

* Mon May 16 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-33
- northd: fix lflow grouping in build_lb_rules
[Gerrit: bfa80196810b3c1306cdb00a032fcc7fb54ba025]
[Upstream: 664f2aa752c48b699499051fa2dbf3a53effd482]

* Thu May 12 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-32
- ovn-controller: Avoid recompute triggered by external_ids:ovn-installed update.
[Gerrit: fcbe70bb7746f7ff7b6f6481a4446ebaf600b030]
[Upstream: fcbe70bb7746f7ff7b6f6481a4446ebaf600b030]

* Wed May 11 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-31
- docs: fix a typo in bandwidth column name
[Gerrit: d41054fcc4926e553139ef4ab13ae65c3f009fcb]
[Upstream: d41054fcc4926e553139ef4ab13ae65c3f009fcb]

* Wed May 11 2022 Ales Musil <amusil@redhat.com> - 22.03.0-30
- ci: ovn-kubernetes: Add missing socat package
[Gerrit: 83d07fee947183253ec95c448b39d62aa6001d7f]
[Upstream: 83d07fee947183253ec95c448b39d62aa6001d7f]

* Tue May 10 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-29
- utilities: ovn-trace: fix reject action crash (#2074537)
[Gerrit: fa7d86a8ae43fa208ef9a3980af396c1feaec92f]
[Upstream: fa7d86a8ae43fa208ef9a3980af396c1feaec92f]

* Tue May 10 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-28
- utilities: nbctl: do not report errors for stateless nat if --may-exist is provided (#2066551)
[Gerrit: ecd073a49eaec04db7de729a087410477e5811bb]
[Upstream: ecd073a49eaec04db7de729a087410477e5811bb]

* Tue May 10 2022 Ales Musil <amusil@redhat.com> - 22.03.0-27
- lflow: Add MAC bindings when new datapath is added to chassis (#2069783)
[Gerrit: ff1e858c99779bdbd48fc4b0d0a1fb39bc9606b9]
[Upstream: ff1e858c99779bdbd48fc4b0d0a1fb39bc9606b9]

* Mon May 09 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-26
- northd: fix nat-v6 with exempted_ext_ips configuration (#2066611)
[Gerrit: 39034eea28cc4b8f79e6af3844fd0d1b7f680bd6]
[Upstream: 39034eea28cc4b8f79e6af3844fd0d1b7f680bd6]

* Mon May 09 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-25
- northd: dynamically compute l2 hdr len for check_pkt_larger action (#2075121)
[Gerrit: 4f3656a20c7756f8ab9a7acae5ec192d37c1bf45]
[Upstream: 4f3656a20c7756f8ab9a7acae5ec192d37c1bf45]

* Thu May 05 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-24
- binding.c: Clear Port_Binding's encap column when encap-ip is removed.
[Gerrit: 83c737e1741b24a58e1df333532529c9afb117a5]
[Upstream: 83c737e1741b24a58e1df333532529c9afb117a5]

* Thu May 05 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-23
- northd: Mark most of the SB columns as write-changed-only. (#2069623)
[Gerrit: c7071900c55d20160e3f2f2241059a8e8dd6a107]
[Upstream: c7071900c55d20160e3f2f2241059a8e8dd6a107]

* Tue Apr 26 2022 Adrian Moreno <amorenoz@redhat.com> - 22.03.0-22
- parallel-hmap: rewrite iterator using multivar helpers
[Gerrit: 3da85a6660776548ddafaa9759b260b0dac38b4b]
[Upstream: 3da85a6660776548ddafaa9759b260b0dac38b4b]

* Tue Apr 26 2022 Adrian Moreno <amorenoz@redhat.com> - 22.03.0-21
- treewide: bump ovs and fix problematic loops
[Gerrit: 985ef4580ac6558859e104bad6fd5e2a68af79f7]
[Upstream: 985ef4580ac6558859e104bad6fd5e2a68af79f7]

* Tue Apr 26 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-20
- Get OVS branch updated to proper base version for upcoming changes.
[Gerrit: 367051dacab28dbe875aba9e1920b5693cf284c3]
[Upstream: 367051dacab28dbe875aba9e1920b5693cf284c3]

* Mon Apr 25 2022 Numan Siddique <numans@ovn.org> - 22.03.0-19
- ovn-northd: Add flow to use eth.src if nd.tll is 0 in put_nd() action. (#2078026)
[Gerrit: bd0ee4c1103ca5eaf834e48093205cacddaadf31]
[Upstream: 80187a8031b6abe01fb23657a9bed2372ae23af5]

* Thu Apr 21 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-18
- Stop sending garps when binding not bound to chassis
[Gerrit: 65088824dbca07dfdf3402d1775d3af76a304ef4]
[Upstream: 65088824dbca07dfdf3402d1775d3af76a304ef4]

* Thu Apr 21 2022 Ales Musil <amusil@redhat.com> - 22.03.0-17
- pinctrl.c: Send GARP only on chassis atached to l3gw (#2062580)
[Gerrit: 77ec310dda51c78c1897011ba851612787fcc6c6]
[Upstream: 77ec310dda51c78c1897011ba851612787fcc6c6]

* Sun Apr 17 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-16
- system-ovn: fix CoPP test failures (#2073060)
[Gerrit: 388446ff27650773716ebcbc332424b1bf82bad1]
[Upstream: e922c05dbb0c0ca70c98bd0b24833248ff5d458b]

* Wed Apr 13 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-15
- ofctrl.c: Check installed flow when merging tracked flow changes. (#2071272)
[Gerrit: 92cdada0e150e937e19f52c98a0c6a6dba7a84e0]
[Upstream: 9c6d285ef2a65aef032cd60f9a9fe16cad7c4222]

* Mon Apr 11 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-14
- northd: avoid writing to IDL in parallel when using northd parallelization
[Gerrit: 6410cb7906121bf2ebec3698d53bcfcb580ca4f6]
[Upstream: 741a135fa1db9e10b725d4b69c6da455f732b89b]

* Thu Apr 07 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-13
- controller/pinctrl: avoid accessing invalid memory (#2052945)
[Gerrit: 55a0ab5d2971daaf22e3d935f623bf7548a3df98]
[Upstream: 6bc6002601ea161a287bcf53524e9282ab97c31b]

* Thu Apr 07 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-12
- northd: avoid snat on reply packets (#2061593)
[Gerrit: be49d5145e10b1e4a525eed3b12d7ffb7818f2d1]
[Upstream: 8b3e1afc30f3cf0ef9857fdc68f619b6fbed10dc]

* Wed Apr 06 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-11
- vtep: correctly bring vtep lport up in SBDB
[Gerrit: 655c3aa74d45791b0de5548c787ee24a147f2456]
[Upstream: b35c98c923f4972198f741ff1d2b28671d6ff50d]

* Wed Apr 06 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-10
- controller: properly remove qos policy meters
[Gerrit: a814b865fbec460c91f9b5037d936b9d518c7a2f]
[Upstream: 1e1d75c725a3445a853dd792b28ff02bb3ab1218]

* Wed Mar 30 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-9
- tests: Make "check CoPP config" more reliable.
[Gerrit: 93e21802ac27ed29f2a4daf58a10912ebd581db5]
[Upstream: 93e21802ac27ed29f2a4daf58a10912ebd581db5]

* Tue Mar 29 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-8
- inc-proc-eng: Properly log recompute reason.
[Gerrit: 3b07a5db4abd921a87b6fdfb851cf27e6975b079]
[Upstream: 3b07a5db4abd921a87b6fdfb851cf27e6975b079]

* Thu Mar 24 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-7
- NEWS: Update the 22.03.0 release date.
[Gerrit: e62886efda51adadd6c01c4e7ee0bbd97994216c]
[Upstream: e62886efda51adadd6c01c4e7ee0bbd97994216c]

* Thu Mar 24 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-6
- rhel: fix logrotate user config option
[Gerrit: 135310cae98e84a637f13e99439566846debcb29]
[Upstream: e8800ddd9e919e2ffc9d8c5c9ab27f0a5a6ec2e5]

* Thu Mar 17 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-5
- northd: Properly warn for NAT on LR with multiple gw ports.
[Gerrit: 622d15d078178e854027358d5130690edbe75a4c]
[Upstream: b8194738c99ee09ad6d4762a3c999e04d58d1a0f]

* Fri Mar 11 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-4
- Prepare for 22.03.1.
[Gerrit: b3d273f73c4aa8d246e652f1fb505779d3828c5b]
[Upstream: b3d273f73c4aa8d246e652f1fb505779d3828c5b]

